"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var os = require("os");
var fs = require("fs-extra");
var cuid = require("cuid");
// TODO replace with process.cwd()
// let cwd = '/Users/tim/code/cli-tests/new'
var cwd = process.cwd();
if (process.env.NODE_ENV === 'test') {
    cwd = path.join(os.tmpdir(), cuid() + "/");
    fs.mkdirpSync(cwd);
}
var home = os.homedir() || os.tmpdir();
if (process.env.NODE_ENV === 'test') {
    home = path.join(os.tmpdir(), cuid() + "/");
    fs.mkdirpSync(home);
}
var Config = (function () {
    function Config(options) {
        /**
         * Local settings
         */
        this.debug = Boolean(process.env.DEBUG && process.env.DEBUG.includes('*'));
        this.windows = false;
        this.bin = 'graphcool';
        this.mock = true;
        this.argv = process.argv.slice(1);
        this.commandsDir = path.join(__dirname, '../dist/commands');
        this.defaultCommand = 'help';
        this.userPlugins = false;
        // TODO inject via package json of module.parent.filepath
        this.version = '1.4';
        this.name = 'graphcool';
        this.pjson = {
            name: 'cli-engine',
            version: '0.0.0',
            dependencies: {},
            'cli-engine': {
                defaultCommand: 'help',
            },
        };
        /**
         * Paths
         */
        this.root = path.join(__dirname, '..');
        this.envPath = path.join(cwd, '.graphcoolrc');
        this.definitionDir = cwd;
        this.home = home;
        this.dotGraphcoolFilePath = path.join(home, '.graphcool');
        this.authUIEndpoint = process.env.ENV === 'DEV'
            ? 'https://dev.console.graph.cool/cli/auth'
            : 'https://console.graph.cool/cli/auth';
        this.backendAddr = process.env.ENV === 'DEV'
            ? 'https://dev.api.graph.cool'
            : 'https://api.graph.cool';
        this.systemAPIEndpoint = process.env.ENV === 'DEV'
            ? 'https://dev.api.graph.cool/system'
            : 'https://api.graph.cool/system';
        this.authEndpoint = process.env.ENV === 'DEV'
            ? 'https://cli-auth-api.graph.cool/dev'
            : 'https://cli-auth-api.graph.cool/prod';
        this.docsEndpoint = process.env.ENV === 'DEV'
            ? 'https://dev.graph.cool/docs'
            : 'https://www.graph.cool/docs';
        this.statusEndpoint = 'https://crm.graph.cool/prod/status';
        /* tslint:disable-next-line */
        this.__cache = {};
        // noop
        if (process.env.NODE_ENV === 'test') {
            this.token = 'test token';
        }
        else {
            if (fs.existsSync(this.dotGraphcoolFilePath)) {
                var configContent = fs.readFileSync(this.dotGraphcoolFilePath, 'utf-8');
                this.token = JSON.parse(configContent).token;
            }
        }
        if (options) {
            this.mock = options.mock;
            this.argv = options.argv || this.argv;
            if (options.root) {
                this.root = options.root;
                var pjsonPath = path.join(options.root, 'package.json');
                var pjson = fs.readJSONSync(pjsonPath);
                if (pjson && pjson['cli-engine']) {
                    this.pjson = pjson;
                    this.version = pjson.version;
                }
            }
        }
    }
    Config.prototype.setToken = function (token) {
        this.token = token;
    };
    Config.prototype.saveToken = function () {
        var json = JSON.stringify({ token: this.token }, null, 2);
        fs.writeFileSync(this.dotGraphcoolFilePath, json);
    };
    Object.defineProperty(Config.prototype, "arch", {
        get: function () {
            return os.arch() === 'ia32' ? 'x86' : os.arch();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Config.prototype, "platform", {
        get: function () {
            return os.platform() === 'win32' ? 'windows' : os.platform();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Config.prototype, "userAgent", {
        get: function () {
            return this.name + "/" + this.version + " (" + this.platform + "-" + this
                .arch + ") node-" + process.version;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Config.prototype, "dirname", {
        get: function () {
            return this.pjson['cli-engine'].dirname || this.bin;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Config.prototype, "cacheDir", {
        get: function () {
            return dir(this, 'cache', this.platform === 'darwin'
                ? path.join(this.home, 'Library', 'Caches')
                : null);
        },
        enumerable: true,
        configurable: true
    });
    return Config;
}());
exports.Config = Config;
function dir(config, category, d) {
    var cacheKey = "dir:" + category;
    var cache = config.__cache[cacheKey];
    if (cache) {
        return cache;
    }
    d =
        d ||
            path.join(config.home, category === 'data' ? '.local/share' : '.' + category);
    if (config.windows) {
        d = process.env.LOCALAPPDATA || d;
    }
    d = process.env.XDG_DATA_HOME || d;
    d = path.join(d, config.dirname);
    fs.mkdirpSync(d);
    config.__cache[cacheKey] = d;
    return d;
}
//# sourceMappingURL=Config.js.map